anubis
======

.. image:: https://img.shields.io/pypi/v/anubis.svg
    :target: https://pypi.python.org/pypi/anubis
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal.png
   :target: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal
   :alt: Latest Travis CI build status

Framework for running bpp qa

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`anubis` was written by `matthew bahloul <matthew.bahloul@blueprintprep.com>`_.
